<?php
/**
 * Plugin Name: Coming Soon Page Maintenance Mode Under Construction Page
 * Plugin URI: http://wordpress.org/plugins/
 * Description: Elegant looking coming soon page, Maintenance Mode & Under construction page. Put your site under maintenance in minutes.
 * Version: 1.0.1
 * Requires at least: 5.2
 * Requires PHP: 7.2
 * Author: EasyToolbox
 * Author URI: https://easytoolbox.net/
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: et-coming-soon-page
 * Domain Path: /languages
 */

 if(!defined('ABSPATH')){
     exit;
 }

 require_once __DIR__ . '/vendor/autoload.php';
 
 /**
  * Plugins Main Class
  */
final class Et_Comming_Soon_Page
{ 
    /**
    * Plugin version
    *
    * @var string
    */
   const et_plugin_version = '1.0.0';

    /**
     * Constructor
     */
    private function __construct()
    {
        $this->define_constants();

        register_activation_hook(__FILE__,[$this,'activate']);
        
        add_action('plugins_loaded',[$this, 'init_plugin']);
    }

    /**
     * Singletone instance instintiate
     * 
     * @return \Et_Comming_Soon_Page
     */
    public static function init(){
        static $instance = false;

        if( ! $instance ){
            $instance = new self();
        }

        return $instance;
    }

    
    /**
     * Plugin constants
     *
     * @return void
     */
    public function define_constants() {
        define( 'ET_COMING_SOON_PAGE_VERSION' , self::et_plugin_version );
        define( 'ET_COMING_SOON_PAGE_FILE'    , __FILE__ );
        define( 'ET_COMING_SOON_PAGE_PATH'    , __DIR__ );
        define( 'ET_COMING_SOON_PAGE_URL'     , plugins_url( '' , ET_COMING_SOON_PAGE_FILE ) );
        define( 'ET_COMING_SOON_PAGE_ASSETS'  , ET_COMING_SOON_PAGE_URL . '/assets' );
    }


    /**
     * Initialize the plugin
     *
     * @return void
     */
    public function init_plugin() {
        new \Et\CommingSoonPage\Assets();
        if ( is_admin() ) {
            new Et\CommingSoonPage\Backend();
        } else {
            new Et\CommingSoonPage\Frontend();
        }
    }
    
    /**
     * save first instellation date and current version in database
     *
     * @return void
     */
    public function activate(){
        $installed = get_option( 'et_comming_soon_page_installed' );

        if ( ! $installed ) {
            update_option( 'et_comming_soon_page_installed', time() );
            $default_general_settings = Array ( "is_active" => 0, "company_name" => "Company Name", "message" => "Site will be live in" );
            update_option( 'et_coming_soon_page_general_settings', $default_general_settings );
        }
        
        update_option( 'et_comming_soon_page_version', ET_COMING_SOON_PAGE_VERSION );
    }
}


/**
 * Main plugin initialization
 *
 * @return \Et_Comming_Soon_Page
 */
function et_comming_soon_page() {
    return Et_Comming_Soon_Page::init();
}

// start the plugin
et_comming_soon_page();